@@ -42,7 +42,6 @@ To get the current switching status (UP/DOWN) of a downstream port 2.
 
 $ ykushcmd -g 2
 """
-import os
 import subprocess
 
 from gazoo_device import decorators
@@ -56,8 +55,6 @@ from gazoo_device.utility import host_utils
 
 logger = gdm_logger.get_logger()
 
-yepkit_enabled = not bool(os.system("which ykushcmd > /dev/null"))
-
 MODEL = "yepkit"
 PRODUCT_ID = "f2f7"
 VENDOR_ID = "04d8"
@@ -77,6 +74,16 @@ REGEXES = {
 TIMEOUTS = {}
 
 
+def _check_yepkit_enabled():
+  """Checks that the host has 'ykushcmd' installed.
+
+  Raises:
+    DependencyUnavailableError: if 'ykushcmd' is not installed.
+  """
+  if not host_utils.has_command("ykushcmd"):
+    raise errors.DependencyUnavailableError("'ykushcmd' is not installed.")
+
+
 class Yepkit(auxiliary_device.AuxiliaryDevice):
   """This class serves as a Python interface to a Yepkit hub."""
   COMMUNICATION_TYPE = "YepkitComms"
@@ -103,8 +110,7 @@ class Yepkit(auxiliary_device.AuxiliaryDevice):
     Raises:
         RuntimeError: if yepkit is not enabled.
     """
-    if not yepkit_enabled:
-      raise RuntimeError("yepkit is not enabled.")
+    _check_yepkit_enabled()
 
     super().__init__(
         manager,
@@ -115,6 +121,12 @@ class Yepkit(auxiliary_device.AuxiliaryDevice):
     self._regexes.update(REGEXES)
     self._timeouts.update(TIMEOUTS)
 
+  @decorators.LogDecorator(logger)
+  def get_console_configuration(self) -> None:
+    """Returns None. Console is not supported because there's no Switchboard."""
+    del self  # Unused because console is not supported.
+    return None
+
   @decorators.PersistentProperty
   def health_checks(self):
     """Returns list of methods to execute as health checks."""
@@ -160,9 +172,6 @@ class Yepkit(auxiliary_device.AuxiliaryDevice):
 
         optional: {}
     """
-    if not yepkit_enabled:
-      raise RuntimeError("yepkit is not enabled.")
-
     if len(self.communication_address) < 4:
       raise RuntimeError("{} serial number {} is too short. "
                          "Length of serial number must be >= 4".format(
