@@ -13,13 +13,14 @@
 # limitations under the License.
 
 """Base class for all auxiliary devices."""
+import atexit
 import difflib
 import functools
 import inspect
 import os
 import re
 import time
-from typing import List, Set, Type
+from typing import Any, List, Set, Type
 import weakref
 
 from gazoo_device import config
@@ -32,6 +33,7 @@ from gazoo_device.capabilities.interfaces import capability_base
 from gazoo_device.switchboard import log_process
 from gazoo_device.utility import common_utils
 from gazoo_device.utility import deprecation_utils
+from gazoo_device.utility import retry
 
 logger = gdm_logger.get_logger()
 
@@ -80,7 +82,7 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
           the log file.
     """
     self._log_object_lifecycle_event("__init__")
-    self.manager_weakref = weakref.ref(manager)
+    self._manager_weakref = weakref.ref(manager)
 
     # Create a dictionary to store "properties".  For now keep the
     # classification of "persistent" and "optional".
@@ -104,6 +106,10 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     self._user_count = 1  # Successive create_device calls just increment the
     # user count and reuse the same instance.
 
+    # b/201669630: Ensure the device instance is closed (again) if it's
+    # continued to be used after an explicit <device>.close() call.
+    atexit.register(common_utils.MethodWeakRef(self.close), force=True)
+
   @decorators.OptionalProperty
   def alias(self):
     """Returns the user-defined device alias (string)."""
@@ -249,8 +255,8 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     """Releases all resources."""
     self.reset_all_capabilities()
 
-    if hasattr(self, "manager_weakref"):
-      manager_instance = self.manager_weakref()
+    if hasattr(self, "_manager_weakref"):
+      manager_instance = self._manager_weakref()
       if manager_instance is not None:
         # pylint: disable=protected-access
         if self.name in manager_instance._open_devices:
@@ -271,7 +277,7 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     """
     device_config = {"persistent": self.props["persistent_identifiers"]}
     try:
-      common_utils.retry(
+      retry.retry(
           func=self.is_connected,
           func_args=(device_config,),
           is_successful=bool,
@@ -307,6 +313,18 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     capability_property = getattr(type(self), capability_name)
     return list(capability_property.capability_classes)
 
+  def get_manager(self) -> Any:  # Returns a Manager instance.
+    """Returns the Manager instance if it is still alive.
+
+    Raises:
+      RuntimeError: If the Manager instance is no longer alive.
+    """
+    manager = self._manager_weakref()
+    if manager is None:
+      raise RuntimeError(f"{self.name}'s Manager is no longer alive. "
+                         "Has the device been closed?'")
+    return manager
+
   def get_dynamic_properties(self):
     """Returns a dictionary of prop, value for each dynamic property."""
     names = self.get_dynamic_property_names()
@@ -378,14 +396,15 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
     return self._get_properties(names)
 
   @classmethod
-  def get_supported_capabilities(cls):
-    """Returns a list of names of capabilities supported by this device class."""
-    # Deduplicate names: there may be several flavors which share the same interface
+  def get_supported_capabilities(cls) -> List[str]:
+    """Returns names of capabilities supported by this device class."""
+    # Deduplicate names: there may be several flavors which share the same
+    # interface.
     capability_names = {
         capability_class.get_capability_name()
         for capability_class in cls.get_supported_capability_flavors()
     }
-    return sorted(list(capability_names))
+    return sorted(capability_names)
 
   @classmethod
   def get_supported_capability_flavors(
@@ -710,7 +729,7 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
         DeviceNotResponsiveError: if no response to ping before the timeout.
     """
     try:
-      common_utils.retry(
+      retry.retry(
           self._ping,
           is_successful=bool,
           timeout=self._PING_TIMEOUT,
@@ -741,9 +760,9 @@ class AuxiliaryDevice(auxiliary_device_base.AuxiliaryDeviceBase):
 
       try:
         health_check_method()
-      except errors.CheckDeviceReadyError:
-        logger.info("{} health check {}/{} failed: {}.".format(
-            self.name, step + 1, len(health_checks), health_check_name))
+      except errors.CheckDeviceReadyError as err:
+        logger.info("{} health check {}/{} {!r} failed: {!r}.".format(
+            self.name, step + 1, len(health_checks), health_check_name, err))
         raise
 
       logger.info("{} health check {}/{} succeeded: {}.".format(
