@@ -15,12 +15,12 @@
 """Base class module for Espressif ESP32 platform device."""
 import os
 from typing import Dict, Tuple
+
+from gazoo_device import console_config
 from gazoo_device import custom_types
 from gazoo_device import decorators
-from gazoo_device import errors
 from gazoo_device import gdm_logger
 from gazoo_device.base_classes import auxiliary_device
-from gazoo_device.switchboard import switchboard
 from gazoo_device.utility import usb_utils
 
 logger = gdm_logger.get_logger()
@@ -35,6 +35,10 @@ class EspressifESP32Device(auxiliary_device.AuxiliaryDevice):
   COMMUNICATION_TYPE = "PigweedSerialComms"
   _COMMUNICATION_KWARGS = {"protobufs": None, "baudrate": BAUDRATE}
 
+  def get_console_configuration(self) -> console_config.ConsoleConfiguration:
+    """Returns the interactive console configuration."""
+    return console_config.get_log_only_configuration()
+
   @decorators.LogDecorator(logger)
   def get_detection_info(self) -> Tuple[Dict[str, str], Dict[str, str]]:
     """Gets the persistent and optional attributes of a device during setup.
@@ -63,21 +67,3 @@ class EspressifESP32Device(auxiliary_device.AuxiliaryDevice):
   @decorators.PersistentProperty
   def platform(self) -> str:
     return "ESP32"
-
-  @decorators.CapabilityDecorator(switchboard.SwitchboardDefault)
-  def switchboard(self):
-    """Instance for communicating with the device."""
-    if self._COMMUNICATION_KWARGS.get("protobufs") is None:
-      raise errors.DeviceError(
-          "Calling switchboard from a non Pigweed device {}".format(self.name))
-    name = self._get_private_capability_name(switchboard.SwitchboardDefault)
-    if not hasattr(self, name):
-      kwargs = self._COMMUNICATION_KWARGS.copy()
-      kwargs.update({
-          "communication_address": self.communication_address,
-          "communication_type": self.COMMUNICATION_TYPE,
-          "log_path": self.log_file_name,
-          "device_name": self.name,
-          "event_parser": None})
-      setattr(self, name, self.manager_weakref().create_switchboard(**kwargs))
-    return getattr(self, name)
