@@ -14,16 +14,18 @@
 
 """Base class for all primary and virtual device classes."""
 # pylint: disable=comparison-with-callable
+import atexit
 import difflib
 import functools
 import inspect
 import os
 import re
 import time
-from typing import List, Set, Type
+from typing import Any, List, Set, Tuple, Type
 import weakref
 
 from gazoo_device import config
+from gazoo_device import data_types
 from gazoo_device import decorators
 from gazoo_device import errors
 from gazoo_device import extensions
@@ -33,6 +35,7 @@ from gazoo_device.capabilities import event_parser_default
 from gazoo_device.capabilities.interfaces import capability_base
 from gazoo_device.switchboard import log_process
 from gazoo_device.switchboard import switchboard
+from gazoo_device.utility import common_utils
 from gazoo_device.utility import deprecation_utils
 
 logger = gdm_logger.get_logger()
@@ -93,7 +96,7 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
   # Absolute paths to event filter files (filters/<device_type>/filter.json)
   _COMMUNICATION_KWARGS = {}
   _CONNECTION_TIMEOUT = 3
-  _DEFAULT_FILTERS = []
+  _DEFAULT_FILTERS = ()  # type: Tuple[str, ...]
   _OWNER_EMAIL = ""  # override in child classes
 
   def __init__(self,
@@ -102,7 +105,7 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
                log_file_name=None,
                log_directory=None):
     self._log_object_lifecycle_event("__init__")
-    self.manager_weakref = weakref.ref(manager)
+    self._manager_weakref = weakref.ref(manager)
 
     # Create a dictionary to store "properties".  For now keep the
     # classification of "persistent" and "optional".
@@ -133,12 +136,8 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     self._regexes = {}
     self._timeouts = TIMEOUTS.copy()
     self.device_type = self.DEVICE_TYPE
-
-    if not self._DEFAULT_FILTERS:
-      logger.warning(f"Device type {self.device_type!r} has no default event "
-                     "filters defined.")
-    self.filter_paths = self._DEFAULT_FILTERS.copy()
-    self.filter_paths += device_config.get("filters") or []
+    self.filter_paths = self._DEFAULT_FILTERS + tuple(
+        device_config.get("filters") or ())
 
     # Initialize log files
     self.log_directory = log_directory
@@ -150,6 +149,10 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
           log_directory, self.name, name_prefix=log_name_prefix)
     self._update_event_filename_and_symlinks()
 
+    # b/201669630: Ensure the device instance is closed (again) if it's
+    # continued to be used after an explicit <device>.close() call.
+    atexit.register(common_utils.MethodWeakRef(self.close))
+
   @decorators.OptionalProperty
   def alias(self):
     """Returns the user-defined device alias (string)."""
@@ -295,8 +298,8 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     """
     self.reset_all_capabilities()
 
-    if hasattr(self, "manager_weakref"):
-      manager_instance = self.manager_weakref()
+    if hasattr(self, "_manager_weakref"):
+      manager_instance = self._manager_weakref()
       if manager_instance is not None:
         if self.name in manager_instance._open_devices:
           self._log_object_lifecycle_event("close")
@@ -323,8 +326,7 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     if hasattr(self, "comm_power"):
       try:
         self.comm_power.health_check()
-      except errors.CapabilityNotReadyError as err:
-        logger.debug(str(err))
+      except errors.CapabilityNotReadyError:
         logger.info("{}'s comm_power capability is not set up.".format(
             self.name))
 
@@ -332,11 +334,22 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     if hasattr(self, "device_power"):
       try:
         self.device_power.health_check()
-      except errors.CapabilityNotReadyError as err:
-        logger.debug(str(err))
+      except errors.CapabilityNotReadyError:
         logger.info("{}'s device_power capability is not set up.".format(
             self.name))
 
+  def get_manager(self) -> Any:  # Returns a Manager instance.
+    """Returns the Manager instance if it is still alive.
+
+    Raises:
+      RuntimeError: If the Manager instance is no longer alive.
+    """
+    manager = self._manager_weakref()
+    if manager is None:
+      raise RuntimeError(f"{self.name}'s Manager is no longer alive. "
+                         "Has the device been closed?'")
+    return manager
+
   def get_dynamic_properties(self):
     """Returns a dictionary of prop, value for each dynamic property."""
     names = self.get_dynamic_property_names()
@@ -468,7 +481,8 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     return bool(self.serial_number)
 
   @decorators.LogDecorator(logger, decorators.DEBUG)
-  def make_device_ready(self, setting: str = "on") -> None:
+  def make_device_ready(
+      self, setting: data_types.MAKE_DEVICE_READY_SETTING = "on") -> None:
     """Checks device readiness and attempts recovery if allowed.
 
     If setting is 'off': does nothing.
@@ -574,7 +588,15 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
       logger.info(
           "{} failed to create switchboard. Power cycling communication port"
           .format(self.name))
-      self.comm_power.cycle()
+
+      try:
+        self.comm_power.cycle()
+      except errors.CapabilityNotReadyError as err:
+        logger.info("{}'s comm_power capability encountered an error: {!r}"
+                    "Unable to power cycle communication port. "
+                    "Try manually power cycling communication port.".format(
+                        self.name, err))
+        raise error
     else:
       raise error
 
@@ -624,14 +646,15 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
     return sorted(names)
 
   @classmethod
-  def get_supported_capabilities(cls):
-    """Returns a list of names of capabilities supported by this device class."""
-    # Deduplicate names: there may be several flavors which share the same interface
+  def get_supported_capabilities(cls) -> List[str]:
+    """Returns names of capabilities supported by this device class."""
+    # Deduplicate names: there may be several flavors which share the same
+    # interface.
     capability_names = {
         capability_class.get_capability_name()
         for capability_class in cls.get_supported_capability_flavors()
     }
-    return sorted(list(capability_names))
+    return sorted(capability_names)
 
   @classmethod
   def get_supported_capability_flavors(
@@ -856,7 +879,7 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
       return ""
 
   @decorators.CapabilityDecorator(switchboard.SwitchboardDefault)
-  def switchboard(self):
+  def switchboard(self) -> switchboard.SwitchboardDefault:
     """Instance for communicating with the device."""
     switchboard_name = self._get_private_capability_name(
         switchboard.SwitchboardDefault)
@@ -868,7 +891,7 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
       switchboard_kwargs["device_name"] = self.name
       switchboard_kwargs["event_parser"] = self.event_parser
       setattr(self, switchboard_name,
-              self.manager_weakref().create_switchboard(**switchboard_kwargs))
+              self.get_manager().create_switchboard(**switchboard_kwargs))
 
     return getattr(self, switchboard_name)
 
@@ -902,8 +925,8 @@ class GazooDeviceBase(primary_device_base.PrimaryDeviceBase):
       try:
         health_check_method()
       except errors.CheckDeviceReadyError as err:
-        logger.info("{} health check {}/{} failed: {}.".format(
-            self.name, step + 1, len(health_checks), health_check_name))
+        logger.info("{} health check {}/{} {!r} failed: {!r}.".format(
+            self.name, step + 1, len(health_checks), health_check_name, err))
         err.checks_passed = checks_passed
         err.properties = self.props["persistent_identifiers"].copy()
         raise
