@@ -14,22 +14,18 @@
 
 """Default implementation of the Pigweed RPC device common capability."""
 import time
-from typing import Any, Callable, Optional
+from typing import Any, Callable
 from gazoo_device import decorators
 from gazoo_device import errors
 from gazoo_device import gdm_logger
 from gazoo_device.capabilities.interfaces import pwrpc_common_base
+from gazoo_device.protos import device_service_pb2
 from gazoo_device.switchboard.transports import pigweed_rpc_transport
-try:
-  # pylint: disable=g-import-not-at-top
-  # pytype: disable=import-error
-  from device_service import device_service_pb2
-  # pytype: enable=import-error
-except ImportError:
-  device_service_pb2 = None
+
 
 logger = gdm_logger.get_logger()
-_RPC_TIMEOUT = 10
+_POLL_INTERVAL_SEC = 0.5  # seconds
+_DEFAULT_BOOTUP_TIMEOUT = 30  # seconds
 
 
 class PwRPCCommonDefault(pwrpc_common_base.PwRPCCommonBase):
@@ -38,18 +34,17 @@ class PwRPCCommonDefault(pwrpc_common_base.PwRPCCommonBase):
   def __init__(self,
                device_name: str,
                switchboard_call: Callable[..., Any],
-               switchboard_call_expect: Callable[..., Any]):
+               rpc_timeout_s: int):
     """Create an instance of the PwRPCCommonDefault capability.
 
     Args:
       device_name: Device name used for logging.
       switchboard_call: The switchboard.call method which calls to the endpoint.
-        See more examples in nrf_pigweed_lighting.py.
-      switchboard_call_expect: The switchboard.call_and_expect method.
+      rpc_timeout_s: Timeout (s) for RPC call.
     """
     super().__init__(device_name=device_name)
     self._switchboard_call = switchboard_call
-    self._switchboard_call_expect = switchboard_call_expect
+    self._rpc_timeout_s = rpc_timeout_s
 
   @decorators.DynamicProperty
   def vendor_id(self) -> str:
@@ -68,124 +63,39 @@ class PwRPCCommonDefault(pwrpc_common_base.PwRPCCommonBase):
 
   @decorators.CapabilityLogDecorator(logger)
   def reboot(self,
-             no_wait: bool = False,
-             rpc_timeout_s: int = _RPC_TIMEOUT,
-             bootup_logline_regex: Optional[str] = None,
-             bootup_timeout: Optional[int] = None):
+             verify: bool = True,
+             bootup_timeout_s: int = _DEFAULT_BOOTUP_TIMEOUT) -> None:
     """Reboots the device.
 
     Args:
-      no_wait: Return before reboot completes.
-      rpc_timeout_s: Timeout (s) for RPC call.
-      bootup_logline_regex: Device logline indicating booting up, not applicable
-        if no_wait is True.
-      bootup_timeout: Timeout (s) to wait for the bootup message, not applicable
-        if no_wait is True.
+      verify: If true, waits for device bootup completes before returning.
+      bootup_timeout_s: Timeout (s) to wait for the device to boot up.
     """
-    if no_wait:
-      self._trigger_device_action(action="Reboot",
-                                  rpc_timeout_s=rpc_timeout_s)
-    else:
-      self._trigger_device_action(action="Reboot",
-                                  rpc_timeout_s=rpc_timeout_s,
-                                  expect_regex=bootup_logline_regex,
-                                  expect_timeout_s=bootup_timeout)
-      self._wait_for_bootup_complete(bootup_timeout)
+    self._trigger_device_action(action="Reboot")
+    if verify:
+      self.wait_for_bootup_complete(bootup_timeout_s)
 
   @decorators.CapabilityLogDecorator(logger)
   def factory_reset(self,
-                    no_wait: bool = False,
-                    rpc_timeout_s: int = _RPC_TIMEOUT,
-                    bootup_logline_regex: Optional[str] = None,
-                    bootup_timeout: Optional[int] = None):
+                    verify: bool = True,
+                    bootup_timeout_s: int = _DEFAULT_BOOTUP_TIMEOUT) -> None:
     """Factory resets the device.
 
     Args:
-      no_wait: Return before factory-reset completes.
-      rpc_timeout_s: Timeout (s) for RPC call.
-      bootup_logline_regex: Device logline indicating booting up, not applicable
-      if no_wait is True.
-      bootup_timeout: Timeout (s) to wait for the bootup message, not applicable
-      if no_wait is True.
+      verify: If true, waits for device bootup completes before returning.
+      bootup_timeout_s: Timeout (s) to wait for the device to boot up.
     """
-    if no_wait:
-      self._trigger_device_action(action="FactoryReset",
-                                  rpc_timeout_s=rpc_timeout_s)
-    else:
-      self._trigger_device_action(action="FactoryReset",
-                                  rpc_timeout_s=rpc_timeout_s,
-                                  expect_regex=bootup_logline_regex,
-                                  expect_timeout_s=bootup_timeout)
-      self._wait_for_bootup_complete(bootup_timeout)
+    self._trigger_device_action(action="FactoryReset")
+    if verify:
+      self.wait_for_bootup_complete(bootup_timeout_s)
 
   @decorators.CapabilityLogDecorator(logger)
-  def ota(self):
+  def ota(self) -> None:
     """Triggers OTA to the device."""
-    self._trigger_device_action("TriggerOta")
+    self._trigger_device_action(action="TriggerOta")
 
-  def _get_static_info(self, property_name: str) -> str:
-    """Returns device static information.
-
-    Args:
-      property_name: Static property name which currently supports: vendor_id,
-        product_id and software_version.
-
-    Raises:
-      DeviceError: The ack status is not true or an invalid property_name is
-      given.
-    """
-    ack, payload_in_bytes = self._switchboard_call(
-        method=pigweed_rpc_transport.PigweedRPCTransport.rpc,
-        method_args=("Device", "GetDeviceInfo"),
-        method_kwargs={})
-    if not ack:
-      raise errors.DeviceError(
-          f"{self._device_name} getting static info failed.")
-    payload = device_service_pb2.DeviceInfo.FromString(payload_in_bytes)
-    device_property = getattr(payload, property_name, None)
-    if device_property is None:
-      raise errors.DeviceError(f"{property_name} doesn't exist in static info.")
-    return device_property
-
-  def _trigger_device_action(
-      self,
-      action: str,
-      rpc_timeout_s: int = _RPC_TIMEOUT,
-      expect_regex: Optional[str] = None,
-      expect_timeout_s: Optional[int] = None) -> None:
-    """Triggers specific device action.
-
-    Args:
-      action: Device actions including reboot, factory-reset and OTA.
-      rpc_timeout_s: Timeout (s) for RPC call.
-      expect_regex: Expected device logline regex.
-      expect_timeout_s: Timeout (s) to wait for the expected regex.
-
-    Raises:
-      DeviceError: The ack status is not true.
-    """
-    if expect_regex is None and expect_timeout_s is None:
-      ack, _ = self._switchboard_call(
-          method=pigweed_rpc_transport.PigweedRPCTransport.rpc,
-          method_args=("Device", action),
-          method_kwargs={"pw_rpc_timeout_s": rpc_timeout_s})
-    elif expect_regex is not None and expect_timeout_s is not None:
-      _, (ack, _) = self._switchboard_call_expect(
-          method=pigweed_rpc_transport.PigweedRPCTransport.rpc,
-          pattern_list=[expect_regex],
-          timeout=expect_timeout_s,
-          method_args=("Device", action),
-          method_kwargs={"pw_rpc_timeout_s": rpc_timeout_s},
-          raise_for_timeout=True)
-    else:
-      raise ValueError("Only one of \"expect_regex\", \"expect_timeout_s\" "
-                       "arguments was provided. Both or neither should be "
-                       "provided.")
-    if not ack:
-      raise errors.DeviceError(f"{self._device_name} triggering {action} failed"
-                               ": The action did not succeed")
-
-  def _wait_for_bootup_complete(self, bootup_timeout: int):
+  @decorators.CapabilityLogDecorator(logger)
+  def wait_for_bootup_complete(self, bootup_timeout: int) -> None:
     """Waits for device to boot up.
 
     Args:
@@ -205,5 +115,47 @@ class PwRPCCommonDefault(pwrpc_common_base.PwRPCCommonBase):
         return
       except errors.DeviceError:
         logger.debug(f"{self._device_name} hasn't booted up yet.")
-      time.sleep(0.5)
+      time.sleep(_POLL_INTERVAL_SEC)
     raise errors.DeviceError(f"Failed to boot up within {bootup_timeout}s.")
+
+  def _get_static_info(self, property_name: str) -> str:
+    """Returns device static information.
+
+    Args:
+      property_name: Static property name which currently supports: vendor_id,
+        product_id and software_version.
+
+    Raises:
+      DeviceError: The ack status is not true or an invalid property_name is
+      given.
+    """
+    ack, payload_in_bytes = self._switchboard_call(
+        method=pigweed_rpc_transport.PigweedRPCTransport.rpc,
+        method_args=("Device", "GetDeviceInfo"),
+        method_kwargs={"pw_rpc_timeout_s": self._rpc_timeout_s})
+    if not ack:
+      raise errors.DeviceError(
+          f"{self._device_name} getting static info failed.")
+    payload = device_service_pb2.DeviceInfo.FromString(payload_in_bytes)
+    device_property = getattr(payload, property_name, None)
+    if device_property is None:
+      raise errors.DeviceError(f"{property_name} doesn't exist in static info.")
+    return device_property
+
+  def _trigger_device_action(self, action: str) -> None:
+    """Triggers specific device action.
+
+    Args:
+      action: Device actions including reboot, factory-reset and OTA.
+
+    Raises:
+      DeviceError: The ack status is not true.
+    """
+    ack, _ = self._switchboard_call(
+        method=pigweed_rpc_transport.PigweedRPCTransport.rpc,
+        method_args=("Device", action),
+        method_kwargs={"pw_rpc_timeout_s": self._rpc_timeout_s})
+
+    if not ack:
+      raise errors.DeviceError(f"{self._device_name} triggering {action} failed"
+                               ": The action did not succeed")
