@@ -13,9 +13,12 @@
 # limitations under the License.
 
 """Simple data types without dependencies on other gazoo_device modules."""
+import dataclasses
 import enum
 
-import dataclasses
+from typing_extensions import Literal
+
+MAKE_DEVICE_READY_SETTING = Literal["on", "off", "check_only", "flash_build"]
 
 
 @enum.unique
