@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Manager module.
 
   - detects devices
@@ -19,36 +18,38 @@
   - get props and sets optional props
 """
 import atexit
+import collections
 import copy
 import datetime
 import difflib
-import fnmatch
 import inspect
 import json
 import logging
-import multiprocessing
 import os
 import queue
 import shutil
 import signal
 import time
-from typing import Dict, Optional, Union
+from typing import Any, Dict, List, Mapping, Optional, Type, Union
 
 from gazoo_device import config
 from gazoo_device import custom_types
+from gazoo_device import data_types
 from gazoo_device import device_detector
 from gazoo_device import errors
 from gazoo_device import extensions
 from gazoo_device import gdm_logger
-
+from gazoo_device.base_classes import auxiliary_device
+from gazoo_device.base_classes import gazoo_device_base
 from gazoo_device.capabilities import event_parser_default
+from gazoo_device.capabilities.interfaces import capability_base
+from gazoo_device.capabilities.interfaces import event_parser_base
 from gazoo_device.log_parser import LogParser
 from gazoo_device.switchboard import switchboard
-
 from gazoo_device.usb_port_map import UsbPortMap
 from gazoo_device.utility import common_utils
 from gazoo_device.utility import host_utils
-from gazoo_device.utility import parallel_utils
+from gazoo_device.utility import multiprocessing_utils
 
 logger = gdm_logger.get_logger()
 _EXPECTED_FOLDER_PERMISSIONS = "755"
@@ -73,11 +74,7 @@ class Manager:
 
     self._open_devices = {}
     self.max_log_size = max_log_size
-    # b/141476623: exception queue must not share multiprocessing.Manager()
-    common_utils.run_before_fork()
-    self._exception_queue_manager = multiprocessing.Manager()
-    common_utils.run_after_fork_in_parent()
-    self._exception_queue = self._exception_queue_manager.Queue()
+    self._exception_queue = multiprocessing_utils.get_context().Queue()
 
     # Backwards compatibility for older debug_level=string style __init__
     if not isinstance(debug_level, int):
@@ -161,9 +158,6 @@ class Manager:
 
     if hasattr(self, "_exception_queue"):
       del self._exception_queue
-    if hasattr(self, "_exception_queue_manager"):
-      self._exception_queue_manager.shutdown()
-      del self._exception_queue_manager
 
   def close_open_devices(self):
     """Closes all open devices."""
@@ -190,32 +184,31 @@ class Manager:
     else:
       self._open_devices[device_name].close()
 
-  def create_device(self,
-                    identifier,
-                    new_alias=None,
-                    log_file_name=None,
-                    log_directory=None,
-                    log_to_stdout=None,
-                    skip_recover_device=False,
-                    make_device_ready="on",
-                    filters=None,
-                    log_name_prefix="") -> custom_types.Device:
+  def create_device(
+      self,
+      identifier,
+      new_alias=None,
+      log_file_name=None,
+      log_directory=None,
+      log_to_stdout=None,
+      skip_recover_device=False,
+      make_device_ready: data_types.MAKE_DEVICE_READY_SETTING = "on",
+      filters=None,
+      log_name_prefix="") -> custom_types.Device:
     """Returns created device object by identifier specified.
 
     Args:
-      identifier (str): The identifier string to identify a single device.
-        For simulators, the identifier can be the simulator device type
+      identifier (str): The identifier string to identify a single device. For
+        simulators, the identifier can be the simulator device type
       new_alias (str): A string to replace device's alias kept in file.
       log_file_name (str): A string log file name to use for log results.
       log_directory (str): A directory path to use for storing log file.
       log_to_stdout (bool): Enable streaming of log results to stdout
         (DEPRECATED).
-      skip_recover_device (bool): Don't recover device if it fails ready
-        check.
+      skip_recover_device (bool): Don't recover device if it fails ready check.
       make_device_ready (str): "on", "check_only", "off". Toggles
         make_device_ready.
-      filters (list): paths to custom Parser filter files or directories to
-        use.
+      filters (list): paths to custom Parser filter files or directories to use.
       log_name_prefix (str): string to prepend to log filename.
 
     Returns:
@@ -286,27 +279,26 @@ class Manager:
       raise
     return device_inst
 
-  def create_device_sim(self,
-                        device_type,
-                        log_file_name=None,
-                        log_directory=None,
-                        skip_recover_device=False,
-                        make_device_ready="off",
-                        filters=None,
-                        log_name_prefix="",
-                        build_info_kwargs=None):
+  def create_device_sim(
+      self,
+      device_type,
+      log_file_name=None,
+      log_directory=None,
+      skip_recover_device=False,
+      make_device_ready: data_types.MAKE_DEVICE_READY_SETTING = "off",
+      filters=None,
+      log_name_prefix="",
+      build_info_kwargs=None):
     """Returns created simulated object by device_type specified.
 
     Args:
       device_type (str): The device type of the simulator.
       log_file_name (str): A string log file name to use for log results.
       log_directory (str): A directory path to use for storing log file.
-      skip_recover_device (bool): Don't recover device if it fails ready
-        check.
+      skip_recover_device (bool): Don't recover device if it fails ready check.
       make_device_ready (str): "on", "check_only", "off". Toggles
         make_device_ready.
-      filters (list): paths to custom Parser filter files or directories to
-        use.
+      filters (list): paths to custom Parser filter files or directories to use.
       log_name_prefix (str): string to prepend to log filename.
       build_info_kwargs (dict): build info args by name to pass to upgrade
         method.
@@ -330,19 +322,19 @@ class Manager:
                                               log_directory, build_info_kwargs)
     return device_class
 
-  def create_devices(self,
-                     device_list=None,
-                     device_type=None,
-                     log_to_stdout=None,
-                     category="gazoo",
-                     make_device_ready="on",
-                     log_name_prefix=""):
+  def create_devices(
+      self,
+      device_list=None,
+      device_type=None,
+      log_to_stdout=None,
+      category="gazoo",
+      make_device_ready: data_types.MAKE_DEVICE_READY_SETTING = "on",
+      log_name_prefix=""):
     """Returns list of created device objects from device_list or connected devices.
 
     Args:
       device_list (list): list of mobly configs.
-      device_type (str): filter to just return device instances of list
-        type.
+      device_type (str): filter to just return device instances of list type.
       log_to_stdout (bool): Enable streaming of log results to stdout
         (DEPRECATED).
       category (str): 'gazoo', 'other' or 'all' to filter connected devices.
@@ -401,8 +393,8 @@ class Manager:
 
     Args:
         log_filename (str): filename containing raw, log event data
-        filter_list (list): List of files or directories containing JSON
-          filter files.
+        filter_list (list): List of files or directories containing JSON filter
+          files.
 
     Returns:
         LogParser: object which creates an event file by parsing a log file
@@ -416,25 +408,24 @@ class Manager:
 
   def create_switchboard(
       self,
-      communication_address,
-      communication_type,
-      device_name="unknown",
-      log_path=None,
-      force_slow=False,
-      event_parser=None,
+      communication_address: str,
+      communication_type: str,
+      device_name: str = "unknown",
+      log_path: Optional[str] = None,
+      force_slow: bool = False,
+      event_parser: Optional[event_parser_base.EventParserBase] = None,
       **kwargs):
     """Creates a switchboard instance.
 
     Args:
-      communication_address (str): primary device address for communication.
-        For example, "123.45.56.123", ADB serial number, or serial port path.
-      communication_type (str): identifier for the type of communication.
-      device_name (str): device identifier. Used in stdout.
-      log_path (str): path to write GDM device logs to.
-      force_slow (bool): send device input at human speed. Used for devices with
-        input speed limitations.
-      event_parser (Parser): parses log stream into events and saves them to
-        event file.
+      communication_address: primary device address for communication. For
+        example, "123.45.56.123", ADB serial number, or serial port path.
+      communication_type: identifier for the type of communication.
+      device_name: device identifier. Used in stdout.
+      log_path: path to write GDM device logs to.
+      force_slow: send device input at human speed. Used for devices with input
+        speed limitations.
+      event_parser: parses log stream into events and saves them to event file.
       **kwargs (dict): additional kwargs to pass onto the communication setup.
 
     Returns:
@@ -459,8 +450,10 @@ class Manager:
 
     comm_type_class = extensions.communication_types[communication_type]
 
-    method_args = inspect.getfullargspec(
-        comm_type_class.__init__).args[1:]  # remove self
+    method_args = []
+    for base_class in comm_type_class.__mro__:
+      method_args += inspect.getfullargspec(
+          base_class.__init__).args[1:]  # remove self
     bad_keys = set(kwargs.keys()) - set(method_args)
     if bad_keys:
       raise errors.SwitchboardCreationError(
@@ -542,9 +535,9 @@ class Manager:
        static_ips (list): list of static ips to detect.
        log_directory (str): alternative location to store log from default.
        save_changes (bool): if True, updates the config files.
-       device_configs (None or tuple[dict, dict]): device configs
-         (persistent, options) to pass to the device detector. If None, uses
-         the current Manager configs.
+       device_configs (None or tuple[dict, dict]): device configs (persistent,
+         options) to pass to the device detector. If None, uses the current
+         Manager configs.
 
     Returns:
         None: if save_changes is True.
@@ -616,56 +609,59 @@ class Manager:
       host_utils.verify_key(key_info)
 
   @classmethod
-  def get_all_supported_capabilities(cls):
-    """Returns a map of all capability names supported by GDM.
+  def get_all_supported_capabilities(cls) -> Mapping[str, str]:
+    """Returns all supported capabilities in alphabetic order.
 
     Returns:
-        dict: map from capability name (str) to capability interface name
-        (str).
-              Example: {"file_transfer": "filetransferbase"}.
+      Mapping from capability name to capability interface name.
+      Example: {"file_transfer": "filetransferbase"}.
     """
-    return copy.copy(extensions.capabilities)
+    return collections.OrderedDict(
+        sorted(extensions.capabilities.items(),
+               key=lambda capability_and_if_names: capability_and_if_names[0]))
 
   @classmethod
-  def get_all_supported_capability_interfaces(cls):
-    """Returns a map of all capability interface classes supported by GDM.
+  def get_all_supported_capability_interfaces(
+      cls) -> Mapping[str, Type[capability_base.CapabilityBase]]:
+    """Returns all supported capability interfaces in alphabetic order.
 
     Returns:
-        dict: map from interface name (str) to capability interface class
-        (type).
-              Example: {"filetransferbase": <class FileTransferBase>}.
+      Mapping from interface name to capability interface class.
+      Example: {"filetransferbase": <class FileTransferBase>}.
     """
-    return copy.copy(extensions.capability_interfaces)
+    return collections.OrderedDict(
+        sorted(extensions.capability_interfaces.items(),
+               key=lambda interface_name_and_cls: interface_name_and_cls[0]))
 
   @classmethod
-  def get_all_supported_capability_flavors(cls):
-    """Returns a map of all capability flavor classes supported by GDM.
+  def get_all_supported_capability_flavors(
+      cls) -> Mapping[str, Type[capability_base.CapabilityBase]]:
+    """Returns all supported capability flavors in alphabetic order.
 
     Returns:
-        dict: map from flavor name (str) to capability flavor class (type).
-              Example: {"filetransferscp": <class FileTransferScp>}.
+      Mapping from flavor name to capability flavor class.
+      Example: {"filetransferscp": <class FileTransferScp>}.
     """
-    return copy.copy(extensions.capability_flavors)
+    return collections.OrderedDict(
+        sorted(extensions.capability_flavors.items(),
+               key=lambda flavor_name_and_cls: flavor_name_and_cls[0]))
 
   @classmethod
-  def get_all_supported_device_classes(cls):
-    """Returns a list of all supported primary, sim, and auxiliary devices.
+  def get_all_supported_device_classes(cls) -> List[Type[custom_types.Device]]:
+    """Returns all supported device classes sorted by the class path.
 
     Returns:
-      list: All supported device types. Returns just categories asked for if
-      requested.
+      All supported auxiliary, primary, and virtual device classes.
     """
-    all_classes = copy.copy(extensions.auxiliary_devices)
-    all_classes += copy.copy(extensions.primary_devices)
-    all_classes += copy.copy(extensions.virtual_devices)
-    return all_classes
+    return sorted(extensions.auxiliary_devices + extensions.primary_devices
+                  + extensions.virtual_devices,
+                  key=lambda a_cls: a_cls.__module__ + "." + a_cls.__name__)
 
   def get_connected_devices(self, category="gazoo"):
     """Retrieve a list of connected devices for the category specified.
 
     Args:
-      category (str): device category ('gazoo', 'other', or 'all') to
-        retrieve.
+      category (str): device category ('gazoo', 'other', or 'all') to retrieve.
 
     Returns:
       list: List of known connected devices.
@@ -686,8 +682,7 @@ class Manager:
 
     Args:
         identifier (str): Name or alias to search for.
-        category (str): device category ('gazoo', 'other' or 'all') to
-          retrieve.
+        category (str): device category ('gazoo', 'other' or 'all') to retrieve.
 
     Returns:
       dict: Configuration obtained for the device found.
@@ -738,8 +733,8 @@ class Manager:
     """Gets an prop's value for device or GDM configuration depends on identifier.
 
     Args:
-        device_name (str): "manager", name, serial_number, alias, or
-          adb_serial of the device.
+        device_name (str): "manager", name, serial_number, alias, or adb_serial
+          of the device.
         prop (str): Public prop available in device_options.json or gdm.json.
           Default is None.
 
@@ -754,62 +749,67 @@ class Manager:
       return self._get_device_prop(device_name, prop)
 
   @classmethod
-  def get_supported_auxiliary_device_classes(cls):
-    return copy.copy(extensions.auxiliary_devices)
+  def get_supported_auxiliary_device_classes(
+      cls) -> List[Type[auxiliary_device.AuxiliaryDevice]]:
+    """Returns all supported auxiliary device classes sorted by class path."""
+    return sorted(extensions.auxiliary_devices,
+                  key=lambda a_cls: a_cls.__module__ + "." + a_cls.__name__)
 
   @classmethod
   def get_supported_auxiliary_device_types(cls):
-    return [
-        a_cls.DEVICE_TYPE
-        for a_cls in cls.get_supported_auxiliary_device_classes()
-    ]
+    """Returns all supported auxiliary device types in alphabetic order."""
+    return sorted(a_cls.DEVICE_TYPE
+                  for a_cls in cls.get_supported_auxiliary_device_classes())
 
   @classmethod
-  def get_supported_device_capabilities(cls, device_type):
+  def get_supported_device_capabilities(cls, device_type: str) -> List[str]:
     """Returns a list of names of capabilities supported by the device type.
 
-    This is a wrapper around GazooDeviceBase.get_supported_capabilities() to
+    This is a wrapper around <device_class>.get_supported_capabilities() to
     allow specifying device_type as a string.
 
     Args:
-        device_type (str): device type to query for supported capabilities.
+      device_type: Device type to query for supported capabilities.
 
     Returns:
-        list: list of capability names supported by this device type.
-              For example, (["file_transfer", "usb_hub"]).
+      Capability names supported by this device type.
+      For example, (["file_transfer", "usb_hub"]).
     """
     device_class = cls.get_supported_device_class(device_type)
     return device_class.get_supported_capabilities()
 
   @classmethod
-  def get_supported_device_capability_flavors(cls, device_type):
-    """Returns a set of all capability flavor classes supported by the device type.
+  def get_supported_device_capability_flavors(
+      cls, device_type: str) -> List[Type[capability_base.CapabilityBase]]:
+    """Returns capability flavor classes supported by the device type.
 
-    This is a wrapper around GazooDeviceBase.get_supported_capability_flavors()
+    This is a wrapper around <device_class>.get_supported_capability_flavors()
     to allow specifying device_type as a string.
 
     Args:
-      device_type (str): device type to query for supported capability flavors.
+      device_type: Device type to query for supported capability flavors.
 
     Returns:
-      set: capability flavor classes supported by this device type.
-      Example: {<class 'DevicePowerDefault'>, <class 'FileTransferScp'>}.
+      Capability flavor classes supported by this device type sorted by the
+      class path. For example, [
+        <class 'gazoo_device.capabilities.file_transfer_scp.FileTransferScp'>,
+        <class 'gazoo_device.switchboard.switchboard.SwitchboardDefault'>,
+      ]
     """
     device_class = cls.get_supported_device_class(device_type)
-    return device_class.get_supported_capability_flavors()
+    return sorted(device_class.get_supported_capability_flavors(),
+                  key=lambda a_cls: a_cls.__module__ + "." + a_cls.__name__)
 
   @classmethod
-  def get_supported_device_class(cls, device_type):
-    """Converts device type to device class.
+  def get_supported_device_class(
+      cls, device_type: str) -> Type[custom_types.Device]:
+    """Returns the device class corresponding to the device type.
 
     Args:
-      device_type (str): device type.
-
-    Returns:
-       class: GazooDeviceBase-based class.
+      device_type: Device type.
 
     Raises:
-      DeviceError: if unknown type.
+      DeviceError: If the provided device type is unknown.
     """
     classes = [
         device_class for device_class in cls.get_all_supported_device_classes()
@@ -825,45 +825,42 @@ class Manager:
               device_type, ", ".join(close_matches)))
 
   @classmethod
-  def get_supported_device_types(cls):
-    """Returns a list of all supported device types.
-
-    Returns:
-      list: All supported device types.
-    """
-    return [
-        a_cls.DEVICE_TYPE for a_cls in cls.get_all_supported_device_classes()
-    ]
+  def get_supported_device_types(cls) -> List[str]:
+    """Returns all supported device types in alphabetic order."""
+    return sorted(a_cls.DEVICE_TYPE
+                  for a_cls in cls.get_all_supported_device_classes())
 
   @classmethod
-  def get_supported_primary_device_classes(cls):
-    return copy.copy(extensions.primary_devices)
+  def get_supported_primary_device_classes(
+      cls) -> List[Type[gazoo_device_base.GazooDeviceBase]]:
+    """Returns all supported primary device classes sorted by the class path."""
+    return sorted(extensions.primary_devices,
+                  key=lambda a_cls: a_cls.__module__ + "." + a_cls.__name__)
 
   @classmethod
   def get_supported_primary_device_types(cls):
-    return [
-        a_cls.DEVICE_TYPE
-        for a_cls in cls.get_supported_primary_device_classes()
-    ]
+    """Returns all supported primary device types in alphabetic order."""
+    return sorted(a_cls.DEVICE_TYPE
+                  for a_cls in cls.get_supported_primary_device_classes())
 
   @classmethod
   def get_supported_virtual_device_classes(cls):
-    return copy.copy(extensions.virtual_devices)
+    """Returns all supported virtual device classes sorted by the class path."""
+    return sorted(extensions.virtual_devices,
+                  key=lambda a_cls: a_cls.__module__ + "." + a_cls.__name__)
 
   @classmethod
   def get_supported_virtual_device_types(cls):
-    return [
-        a_cls.DEVICE_TYPE
-        for a_cls in cls.get_supported_virtual_device_classes()
-    ]
+    """Returns all supported virtual device types in alphabetic order."""
+    return sorted(a_cls.DEVICE_TYPE
+                  for a_cls in cls.get_supported_virtual_device_classes())
 
   def is_device_connected(self, identifier, category="all"):
     """Determine if device match identifier provided is connected for the category specified.
 
     Args:
       identifier (str): Name or alias to search for.
-      category (str): device category ('gazoo', 'other', or 'all') to
-        retrieve.
+      category (str): device category ('gazoo', 'other', or 'all') to retrieve.
 
     Returns:
       bool: True if the matching devices is connected. False otherwise.
@@ -926,85 +923,10 @@ class Manager:
     return {key: value for key, value in props_dict.items() if "usb" in key}
 
   def port_map(self):
-    """Prints the USB Port Map.
-    """
+    """Prints the USB Port Map."""
     usb_port_map = UsbPortMap(self)
     usb_port_map.print_port_map()
 
-  def issue_devices(self,
-                    devices,
-                    method_name,
-                    timeout=parallel_utils.TIMEOUT_PROCESS,
-                    **kwargs):
-    """Execute a device method in parallel for multiple devices.
-
-    Args:
-        devices (list): list of device identifiers.
-        method_name (str): name of device method to execute in parallel.
-        timeout (int): maximum amount of seconds to allow parallel methods
-          to complete.
-        **kwargs (dict): arguments to pass to device method.
-
-    Returns:
-        list: list of results from parallel calls.
-    """
-    if isinstance(devices, str):
-      devices = devices.split(",")
-
-    return self._issue_devices(devices, method_name, timeout, **kwargs)
-
-  def issue_devices_all(self,
-                        method_name,
-                        timeout=parallel_utils.TIMEOUT_PROCESS,
-                        **kwargs):
-    """Execute a device method in parallel for all connected devices.
-
-    Args:
-        method_name (str): name of device method to execute in parallel.
-        timeout (int): maximum amount of seconds to allow parallel methods
-          to complete.
-        **kwargs (dict): arguments to pass to device method.
-
-    Returns:
-        list: list of results from parallel calls.
-
-    Raises:
-        DeviceError: if no devices are connected.
-    """
-    devices = self.get_connected_devices()
-    if not devices:
-      raise errors.DeviceError("No devices are connected.")
-
-    return self._issue_devices(devices, method_name, timeout, **kwargs)
-
-  def issue_devices_match(self,
-                          match,
-                          method_name,
-                          timeout=parallel_utils.TIMEOUT_PROCESS,
-                          **kwargs):
-    """Execute a device method in parallel for connected devices that match a given string.
-
-    Args:
-      match (str): wildcard-supported string to match against device
-        names, i.e. "raspberrypi*" will call provided method on all connected
-        Raspberry Pis.
-      method_name (str): name of device method to execute in parallel.
-      timeout (int): maximum amount of seconds to allow parallel methods
-        to complete.
-      **kwargs (dict): arguments to pass to device method.
-
-    Returns:
-      list: results from parallel calls.
-
-    Raises:
-      DeviceError: if provided wildcard does not match any connected devices.
-    """
-    devices = fnmatch.filter(self.get_connected_devices(), match)
-    if not devices:
-      raise errors.DeviceError('No devices match "{}".'.format(match))
-
-    return self._issue_devices(devices, method_name, timeout, **kwargs)
-
   def redetect(self, device_name, log_directory=None):
     """Delete a device from the device configuration and then do a detect to find it again.
 
@@ -1103,10 +1025,9 @@ class Manager:
     """Add new attribute to self.config dict.
 
     Args:
-      key (str): key's name. if there is no such key, a new key will be
-        created.
-      value (str): key's corresponding value. If value is not None, the
-        value is used.
+      key (str): key's name. if there is no such key, a new key will be created.
+      value (str): key's corresponding value. If value is not None, the value is
+        used.
       default (str): default value for key
 
     Raises:
@@ -1133,10 +1054,9 @@ class Manager:
     """Add new path configuration to self.config dict.
 
     Args:
-      key (str): key's name. if there is no such key, a new key will be
-        created.
-      path (str): key's corresponding value. If value is not None, this
-        value is used.
+      key (str): key's name. if there is no such key, a new key will be created.
+      path (str): key's corresponding value. If value is not None, this value is
+        used.
       default (str): default value for key.
 
     Raises:
@@ -1258,8 +1178,8 @@ class Manager:
   def device_has_capabilities(cls, device_type, capability_names):
     """Check whether a device type supports all of the given capabilities.
 
-    This is a wrapper around GazooDeviceBase.has_capabilities() to allow
-        specifying device_type as a string.
+    This is a wrapper around <device_class>.has_capabilities() to allow
+    specifying device_type as a string.
 
     Args:
         device_type (str): device type to query for supported capabilities.
@@ -1270,9 +1190,9 @@ class Manager:
                 - capability flavor names ("filetransferscp").
             If an interface name or capability name is specified, the behavior
             is identical: any capability flavor which implements the given
-            interface will match. If a flavor name is specified, only that
-            capability flavor will match. Different kinds of capability names
-            can be used together (["usb_hub", "filetransferscp"]).
+              interface will match. If a flavor name is specified, only that
+              capability flavor will match. Different kinds of capability names
+              can be used together (["usb_hub", "filetransferscp"]).
 
     Returns:
         bool: True if all capabilities are supported by the device type,
@@ -1285,8 +1205,8 @@ class Manager:
     """Returns a dict of all device name aliases for the category specified.
 
     Args:
-      category (str): Indicates the device category ('gazoo', 'other', or
-        'all') to retrieve.
+      category (str): Indicates the device category ('gazoo', 'other', or 'all')
+        to retrieve.
 
     Returns:
       dict: Device name aliases for the category.
@@ -1324,8 +1244,8 @@ class Manager:
 
     Args:
       name (str): Key to use for obtaining device configuration.
-      category (str): Indicates the device category ('gazoo', 'other' or
-        'all') to retrieve.
+      category (str): Indicates the device category ('gazoo', 'other' or 'all')
+        to retrieve.
 
     Returns:
       dict: Configuration obtained for the device found
@@ -1349,8 +1269,7 @@ class Manager:
         identifier (str): Name or alias to search for.
         category (str): Device category. Options: ('gazoo', 'other', or
           'all') Default: 'all'.
-        raise_error (bool): raise error if unable to find device. Default:
-          False
+        raise_error (bool): raise error if unable to find device. Default: False
 
     Returns:
       str: Device key name to use for the identifier specified.
@@ -1423,8 +1342,7 @@ class Manager:
     """Gets a prop's value for a device if the device and the prop exist.
 
     Args:
-      identifier (str): name, serial_number, alias, or adb_serial of the
-        device.
+      identifier (str): name, serial_number, alias, or adb_serial of the device.
       prop (str): Name of a single property to fetch.
 
     Returns:
@@ -1504,10 +1422,7 @@ class Manager:
       return all_props
     return all_attributes
 
-  def _get_device_class(self,
-                        device_class,
-                        device_config,
-                        log_file_name,
+  def _get_device_class(self, device_class, device_config, log_file_name,
                         log_directory):
     """Returns the device class after adding it to the list of shared resources."""
     device = device_class(
@@ -1530,61 +1445,6 @@ class Manager:
     self._open_devices[device.name] = device
     return device
 
-  def _issue_devices(self,
-                     devices,
-                     method_name,
-                     timeout=parallel_utils.TIMEOUT_PROCESS,
-                     **kwargs):
-    """Execute a device method in parallel for multiple devices.
-
-    Args:
-        devices (list): list of device identifiers.
-        method_name (str): name of device method to execute in parallel.
-        timeout (int): maximum amount of seconds to allow parallel methods
-          to complete.
-        **kwargs (dict): arguments to pass to device method.
-
-    Returns:
-        list: list of results from parallel calls, if any.
-
-    Raises:
-        DeviceError: if a provided device does not have a method with name
-        method_name.
-    """
-    device_names = []
-    parameter_dicts = {}
-    for device_id in devices:
-
-      # collect names of devices that support method
-      device_name = self._get_device_name(device_id, raise_error=True)
-      device_type = self.get_device_configuration(
-          device_name)["persistent"]["device_type"]
-      device_class = self.get_supported_device_class(device_type)
-      if not hasattr(device_class, method_name):
-        raise errors.DeviceError("Device {} does not support method {}".format(
-            device_id, method_name))
-      else:
-        device_names.append(device_name)
-        parameter_dicts[device_type] = kwargs
-
-    # create device instances
-    device_instances = [
-        self.create_device(device_name, make_device_ready="off")
-        for device_name in device_names
-    ]
-
-    # execute device methods in parallel using parallel_utils
-    try:
-      results = parallel_utils.issue_devices_parallel(method_name,
-                                                      device_instances,
-                                                      parameter_dicts, timeout)
-    finally:
-      for device in device_instances:
-        device.close()
-
-    if results:
-      return results
-
   def _load_configuration(self,
                           device_file_name=None,
                           device_options_file_name=None,
@@ -1754,8 +1614,8 @@ class Manager:
     """Sets a property's value for device or GDM configuration depends on identifier.
 
     Args:
-      device_name (str): "manager", name, serial_number, alias, or
-        adb_serial of the device.
+      device_name (str): "manager", name, serial_number, alias, or adb_serial of
+        the device.
       prop (str): Public prop available in device_options.json or gdm.json.
       value (str): Input value for specific property.
 
@@ -1803,7 +1663,7 @@ class Manager:
     Args:
       category (str): 'gazoo' or 'other'.
     """
-    format_line = "{:26} {:15} {:20} {:20} {:10}"
+    format_line = "{:30} {:15} {:24} {:20} {:10}"
     if category == "gazoo":
       device_dict = self._devices
       title = "Device"
@@ -1817,7 +1677,7 @@ class Manager:
     logger.info(
         format_line.format(title, "Alias", "Type", "Model", connected_title))
     logger.info(
-        format_line.format("-" * 26, "-" * 15, "-" * 20, "-" * 20, "-" * 10))
+        format_line.format("-" * 30, "-" * 15, "-" * 24, "-" * 20, "-" * 10))
     for name in sorted(device_dict.keys()):
       device_config = device_dict[name]
       device_type = device_config["persistent"]["device_type"]
@@ -1845,7 +1705,6 @@ class Manager:
 
     try:
       exception_message = self._exception_queue.get_nowait()
-      self._exception_queue.task_done()
     except (queue.Empty, ValueError):
       exception_message = "Exception queue missing exception message on SIGUSR1"
     except AttributeError:
@@ -1857,8 +1716,7 @@ class Manager:
     """Sets a property's value for device.
 
     Args:
-      identifier (str): name, serial_number, alias, or adb_serial of the
-        device.
+      identifier (str): name, serial_number, alias, or adb_serial of the device.
       prop (str): Public prop available in device_options.json.
       value (str): Input value for specific property.
 
@@ -1900,8 +1758,7 @@ class Manager:
     """Removes prop from device config dict and file if in 'options'.
 
     Args:
-      identifier (str): name, serial_number, alias, or adb_serial of the
-        device.
+      identifier (str): name, serial_number, alias, or adb_serial of the device.
       prop (str): Public prop available in device_options.json.
 
     Raises:
@@ -1933,8 +1790,7 @@ class Manager:
     if new_alias is not None:
       self.aliases[new_alias.lower()] = name
 
-  def _set_config_prop(self,
-                       prop: str,
+  def _set_config_prop(self, prop: str,
                        value: custom_types.PropertyValue) -> None:
     """Sets an GDM config property.
 
