@@ -14,37 +14,61 @@
 
 """Utility module for interaction with PwRPC (Pigweed RPC)."""
 import enum
+import importlib
 import os
-from typing import Callable
+from typing import Callable, Generic, TypeVar
 
 from gazoo_device import errors
 from gazoo_device import gdm_logger
 from gazoo_device.capabilities.interfaces import switchboard_base
-from gazoo_device.protos import echo_service_pb2
+from gazoo_device.protos import button_service_pb2
+from gazoo_device.protos import device_service_pb2
+from gazoo_device.protos import lighting_service_pb2
 from gazoo_device.protos import locking_service_pb2
 from gazoo_device.switchboard.transports import pigweed_rpc_transport
 
-# TODO(b/185956488): Remove conditional imports of Pigweed
-try:
-  # pylint: disable=g-import-not-at-top
-  # pytype: disable=import-error
-  from button_service import button_service_pb2
-  from device_service import device_service_pb2
-  from lighting_service import lighting_service_pb2
-  # pytype: enable=import-error
-  _PWRPC_PROTOS = (button_service_pb2,
-                   device_service_pb2,
-                   lighting_service_pb2,
-                   echo_service_pb2,
-                   locking_service_pb2)
-except ImportError:
-  _PWRPC_PROTOS = None
+_PWRPC_PROTOS = (button_service_pb2,
+                 device_service_pb2,
+                 lighting_service_pb2,
+                 locking_service_pb2)
+_ProtobufType = TypeVar("_ProtobufType")
+
+
+class PigweedProtoState(Generic[_ProtobufType]):
+  """Pigweed proto state interface.
+
+  The RPC can accept proto type objects as parameters, however, protobufs aren't
+  picklable, so we'll need this class interface to store the encoded protobuf
+  object (bytes) and decode it back to the protobuf type.
+  """
+
+  def __init__(self, proto_inst: _ProtobufType, decoder_path: str) -> None:
+    """Constructor of the PigweedProtoState.
+
+    Args:
+      proto_inst: Protobuf instance.
+        (ex: lighting_service_pb2.LightingColor(hue=0, saturation=0))
+      decoder_path: The import path of the protobuf class.
+        (ex: gazoo_device.protos.lighting_service_pb2.LightingColor)
+    """
+    self._bytes = proto_inst.SerializeToString()
+    self._decoder_path = decoder_path
+
+  def _get_decoder(self) -> Callable[[bytes], _ProtobufType]:
+    """Gets decoder method from decoder path."""
+    module, proto_class = self._decoder_path.rsplit(".", 1)
+    mod = importlib.import_module(module)
+    return getattr(mod, proto_class).FromString
+
+  def decode(self) -> _ProtobufType:
+    """Decodes the encoded proto instance."""
+    decoder = self._get_decoder()
+    return decoder(self._bytes)
 
 
 class PigweedAppType(enum.Enum):
   NON_PIGWEED = "nonpigweed"
   LIGHTING = "lighting"
-  ECHO = "echo"
   LOCKING = "locking"
 
 logger = gdm_logger.get_logger()
@@ -57,7 +81,6 @@ logger = gdm_logger.get_logger()
 # application_type is the Pigweed device type in string.
 _PIGWEED_APP_ENDPOINTS = (
     (("Lighting", "Get"), {}, PigweedAppType.LIGHTING),
-    (("msg",), {}, PigweedAppType.ECHO),
     (("Locking", "Get"), {}, PigweedAppType.LOCKING)
 )
 
@@ -77,11 +100,6 @@ def get_application_type(
   Returns:
     Pigweed application type.
   """
-  if _PWRPC_PROTOS is None:
-    logger.warning(
-        "Pigweed python packages are not available in this environment.")
-    return PigweedAppType.NON_PIGWEED.value
-
   switchboard = create_switchboard_func(communication_address=address,
                                         communication_type="PigweedSerialComms",
                                         device_name=os.path.basename(log_path),
@@ -90,10 +108,7 @@ def get_application_type(
   try:
     for method_args, method_kwargs, app_type in _PIGWEED_APP_ENDPOINTS:
       try:
-        if app_type == PigweedAppType.ECHO:
-          method = pigweed_rpc_transport.PigweedRPCTransport.echo_rpc
-        else:
-          method = pigweed_rpc_transport.PigweedRPCTransport.rpc
+        method = pigweed_rpc_transport.PigweedRPCTransport.rpc
         switchboard.call(method=method,
                          method_args=method_args,
                          method_kwargs=method_kwargs)
